﻿using UnityEngine;
using System.Collections;

public class Kotori : MonoBehaviour
{
	//接地判定する対象のLayer
	public LayerMask groundLayer;

	//publicなグローバル変数にしておくとGUI上で調整できる
	public float walkForce = 30f;
	public float flyForce = 50f;
	public float maxWalkSpeed = 3f;
	public float maxFlySpeed = 5f;

	//右を向いているかどうか
	private bool facingRight = true;

	void Update()
	{
		//接地しているかどうかを判定する
		//自分の基点の少し上と少し下の2点を渡して、その間にColliderがあればtrueが返る
		bool grounded = Physics2D.Linecast(
			transform.position + transform.up * 1,
			transform.position - transform.up * 0.1f,
			groundLayer
		);
		
		//接地状態を出力する
		//Debug.Log("grounded ->" + grounded);

		//Animatorコンポーネントの「Grounded」プロパティに取得した接地状態を渡す
		GetComponent<Animator>().SetBool("Grounded",grounded);
	}

	void FixedUpdate()
	{
		//左右キーの入力
		float h = Input.GetAxis("Horizontal");
		//上下キーの入力
		float v = Input.GetAxis("Vertical");

		//制限速度以下だったら、
		if(rigidbody2D.velocity.x < maxWalkSpeed)
		{
			//左右キーの入力にあわせて、横方向の力を加える（歩く）
			rigidbody2D.AddForce(Vector2.right * h * walkForce);
		}

		//制限速度以下だったら、かつ上キーの入力だったら（下キーは無視する）
		if(v > 0 && rigidbody2D.velocity.y < maxFlySpeed)
		{
			//上方向の力を加える（飛ぶ）
			rigidbody2D.AddForce(Vector2.up * v * flyForce);
		}

		//制限速度より大きかったら
		if(Mathf.Abs(rigidbody2D.velocity.x) > maxWalkSpeed)
		{
			//自分の速度を制限速度に合わせる
			//飛ぶ動きは、重力がかかって勝手に減速するので、そのまま
			//Mathf.Sign -> 値の符号を取得
			rigidbody2D.velocity = new Vector2(
				Mathf.Sign(rigidbody2D.velocity.x) * maxWalkSpeed,
				rigidbody2D.velocity.y
			);
		}

		//右を向いていて、左の入力があったとき、もしくは左を向いていて、右の入力があったとき
		if((h > 0 && !facingRight) || (h < 0 && facingRight))
		{
			//右を向いているかどうかを、入力方向をみて決める
			facingRight = (h > 0);
			//localScale.xを、右を向いているかどうかで更新する
			transform.localScale = new Vector3((facingRight ? 1 : -1), 1, 1);
		}
	}
}